# Infection

This package will allow you to create a credible set for the patient zero given a set of infected nodes on a graph.

## Installation

Run the following to install:

```python
pip install infect-net-inference
```

## Usage

```python
from  import *


```
